@@ -26,6 +26,8 @@ use experimental qw/postderef signatures/ ;
 my %opt;
 GetOptions (\%opt, "from=s") or die("Error in command line arguments\n");
 
+die "Missing '-from' option " unless $opt{from};
+
 my $systemd_path = path($opt{from});
 die "Can't open directory ".$opt{from}."\n" unless $systemd_path->is_dir;
 
@@ -130,7 +132,8 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info) {
     $desc =~ s/[\s\n]+/ /g;
 
     my $value_type
-        = $desc =~ /Takes an? (boolean|integer)/ ? $1
+        = $desc =~ /Takes a boolean argument or/ ? 'enum'
+        : $desc =~ /Takes an? (boolean|integer)/ ? $1
         : $desc =~ /Takes time \(in seconds\)/   ? 'integer'
         : $desc =~ /Takes one of/                ? 'enum'
         : $extra_info =~ /\w\|\w/                ? 'enum'
@@ -144,22 +147,35 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info) {
 
     push @load, 'type=leaf', "value_type=$value_type";
 
-    if ($extra_info =~ /\w\|\w/) {
-        $extra_info =~ s/\|/,/g;
-        push @load, "choice=$extra_info";
-    }
-    elsif ($desc =~ /Takes one of/) {
-        my ($choices) = ($desc =~ /Takes one of ([^.]+?)(?:\.|to test)/);
-        say "$element found ->$choices<-";
-        $choices =~ s/\(the default\)//g;
-        $choices =~ s/\b(or|and)\b/,/g;
-        $choices =~ s/\s//g;
-        $choices =~ s/C<(\w+)>/$1/g;
-        $choices =~ s/,+/,/g;
-        say "set choice $choices";
-        push @load, qq!choice=$choices!;
+    push @load, 'write_as=no,yes' if $value_type eq 'boolean';
+
+    if ($value_type eq 'enum') {
+        my @choices;
+        if ($extra_info =~ /\w\|\w/) {
+            @choices = split /\|/, $extra_info ;
+        }
+        elsif ($desc =~ /Takes a boolean argument or (?:C<)?([\w-]+)/) {
+            @choices = ('no','yes',$1);
+            push @load, qw/replace:false=no replace:true=yes replace:0=no replace:1=yes/;
+        }
+
+        if ($desc =~ /Takes one of/) {
+            my ($choices) = ($desc =~ /Takes one of ([^.]+?)(?:\.|to test)/);
+            $choices =~ s/\(the default\)//g;
+            $choices =~ s/\b(or|and)\b/,/g;
+            $choices =~ s/\s//g;
+            $choices =~ s/C<(\w+)>/$1/g;
+            $choices =~ s/,+/,/g;
+            say "set choice $choices";
+            @choices = split /,/, $choices;
+        }
+
+        die "Error in $config_class: cannot find the values of $element enum type\n"
+            unless @choices;
+        push @load, 'choice='.join(',',@choices);
     }
 
+
     push @load, "min=$min" if defined $min;
     push @load, "max=$max" if defined $max;
 
@@ -240,13 +256,20 @@ foreach my $cdata ($data->{element}->@*) {
 
 say "Tweaking systemd model...";
 
-$meta_root->load( << "EOL"
-! class:Systemd::Section::Service
-      include:=Systemd::Common::ResourceControl,Systemd::Common::Exec,Systemd::Common::Kill
-
-EOL
+$meta_root->load(
+    'class:Systemd::Section::Service
+     include:=Systemd::Common::ResourceControl,Systemd::Common::Exec,Systemd::Common::Kill'
 );
 
+# doc for IOSchedulingClass is too complicated to parse,
+$meta_root->load(
+    '! class:Systemd::Common::Exec
+       element:IOSchedulingClass value_type:=enum
+                                 choice:=0,1,2,3,none,realtime,best-effort,idle'
+);
+
+
+
 say "Saving systemd model...";
 $rw_obj->write_all;
 
