@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Unit ;
-$Config::Model::Backend::Systemd::Unit::VERSION = '0.006';
+$Config::Model::Backend::Systemd::Unit::VERSION = '0.007';
 use strict;
 use warnings;
 use 5.010;
@@ -96,10 +96,19 @@ sub load_data {
 
         # read data in the model order
         foreach my $elt (@elements) {
-            my $unit_data = $data_ref->{$elt}; # extract relevant data
+            my $unit_data = delete $data_ref->{$elt}; # extract relevant data
             next unless defined $unit_data;
             $scanner->scan_element($unit_data, $node,$elt) ;
         }
+        # read accepted elements
+        foreach my $elt (sort keys %$data_ref) {
+            my $unit_data = $data_ref->{$elt}; # extract relevant data
+
+            # force creation of element (can be removed with Config::Model 2.086)
+            my $obj = $node->fetch_element($elt);
+
+            $scanner->scan_element($unit_data, $node,$elt) ;
+        }
     };
 
     # this setup is required because IniFile backend cannot push value
@@ -186,7 +195,7 @@ Config::Model::Backend::Systemd::Unit - R/W backend for systemd unit files
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
